@@ -227,15 +227,12 @@ class GoferHandler(HubOAuthenticated, tornado.web.RequestHandler):
         self.write("This is a post only page. You probably shouldn't be here!")
 
     @authenticated
-    async def get(self):
-        user_model = self.get_current_user()
-        self.set_header('content-type', 'application/json')
-        self.write(json.dumps(user_model, indent=1, sort_keys=True))
+    def get(self):
         self.write("This is a post only page. You probably shouldn't be here!")
         self.finish()
 
     @authenticated
-    async def post(self):
+    def post(self):
         notebook = None
         section = None
         assignment = None
@@ -415,8 +412,7 @@ def start_server():
                 HubOAuthCallbackHandler,
             )
         ],
-        debug=True,
-        cookie_secret="3625bc32a96fac353d416785d9201e4f78e53364944a1a2c9d3a065dc75b4d5d",
+        cookie_secret=os.urandom(32),
     )
 
     logger = logging.getLogger('tornado.application')
@@ -431,10 +427,9 @@ def start_server():
     access_file_handler = logging.FileHandler(ACCESS_LOG_FILE)
     access_file_handler.setFormatter(formatter)
     access_logger.addHandler(access_file_handler)
-    try:
-        app.listen(10101)
-    except OSError:
-        tornado.ioloop.IOLoop.current().stop()
+
+    app.listen(10101)
+
     return app
 
 
@@ -455,7 +450,6 @@ def main():
         tornado.ioloop.IOLoop.current().start()
     except Exception:
         logging.getLogger('tornado.application').error(traceback.format_exc())
-        
 
 
 if __name__ == '__main__':
